Add missing __hip_pinned_shadow__ attributes to the texture global vars. (#1866)

[ROCm/hip commit: 56b8b0d80e]
This commit is contained in:
vsytch
2020-02-14 23:22:25 -05:00
committed by GitHub
parent e72b5a0187
commit cf57b45f3c
4 changed files with 24 additions and 0 deletions
@@ -26,9 +26,15 @@ THE SOFTWARE.
* HIT_END
*/
#include "test_common.h"
typedef float T;
// Texture reference for 2D Layered texture
#if __HIP__
__hip_pinned_shadow__
#endif
texture<float, hipTextureType2DLayered> tex2DL;
__global__ void simpleKernelLayeredArray(T* outputData,int width,int height,int layer)
{
unsigned int x = blockIdx.x*blockDim.x + threadIdx.x;